@@ -2,8 +2,7 @@ package DBD::Cassandra::dr;
 use v5.14;
 use warnings;
 
-use IO::Socket::INET;
-use DBD::Cassandra::Protocol qw/:all/;
+use DBD::Cassandra::Connection;
 
 # "*FIX ME* Explain what the imp_data_size is, so that implementors aren't
 #  practicing cargo-cult programming" - DBI::DBD docs
@@ -27,10 +26,14 @@ sub connect {
     my $keyspace= delete $attr->{cass_database} || delete $attr->{cass_db} || delete $attr->{cass_keyspace};
     my $host= delete $attr->{cass_host} || 'localhost';
     my $port= delete $attr->{cass_port} || 9042;
+    my $compression= delete $attr->{cass_compression} // 'lz4';
+    my $cql_version= delete $attr->{cass_cql_version} || '3.0.0';
+
+    $compression= '' if $compression eq "none";
 
     my $connection;
     eval {
-        $connection= cass_connect($host, $port, $user, $auth);
+        $connection= DBD::Cassandra::Connection->connect($host, $port, $user, $auth, $compression, $cql_version);
         1;
     } or do {
         my $err= $@ || "unknown error";
@@ -42,39 +45,12 @@ sub connect {
     $dbh->STORE('Active', 1);
     $dbh->{cass_connection}= $connection;
 
-    $outer->do("use $keyspace") if $keyspace;
+    $outer->do("use $keyspace") or return
+        if $keyspace;
 
     return $outer;
 }
 
-sub cass_connect {
-    my ($host, $port, $user, $auth)= @_;
-    my $socket= IO::Socket::INET->new(
-        PeerAddr => $host,
-        PeerPort => $port,
-        Proto    => 'tcp',
-    ) or die "Can't connect: $@";
-
-    {
-        my $body= pack_string_map({ CQL_VERSION => '3.0.0' });
-        send_frame2( $socket, 0, 1, OPCODE_STARTUP, $body )
-            or die "Could not send STARTUP: $!";
-    }
-
-    {
-        my ($flags, $streamid, $opcode, $body)= recv_frame2($socket);
-        if ($streamid != 1) {
-            die "Server replied with a wrong StreamID";
-        }
-
-        if ($opcode != OPCODE_READY) {
-            die "Server sent an unsupported opcode";
-        }
-    }
-
-    return $socket;
-}
-
 sub data_sources {
     my ($drh, $attr)= @_;
     my @array= (qw/dbi:Cassandra/);
